@@ -1151,6 +1151,10 @@ def parse(full=False):
         parser.add_argument(
             '--pid-file', type=str, dest='pidfile',
             help=_('Specify the location of the PID file'))
+        parser.add_argument(
+            '--close-on-inactive', action='store_true', dest='inactiveclose',
+            default=False,
+            help=_('stop the server if there are no active sessions'))
         parser.add_argument(
             '--cert', type=str, dest='Id',
             help=_('operations with certificates (number or "all"). Server not'
