@@ -21,6 +21,7 @@ import re
 from calculate.lib.utils.common import getpass
 from calculate.lib.cl_print import color_print
 from calculate.lib.cl_lang import setLocalTranslate
+from calculate.core.server.api_types import TableAdapter
 
 _ = lambda x: x
 setLocalTranslate('cl_core3', sys.modules[__name__])
@@ -356,42 +357,37 @@ def set_table_pwd(client, param_object, field, value):
                         found_flag = True
                         break
 
+    # код выполняется через сетевую консоль
     if client:
         if not getattr(param_object, field.name):
             setattr(param_object, field.name, field.tablevalue.body)
-
-        result = []
-        for _array in param_object[field.name].stringArray:
-            temp = []
-            for item in _array.string:
-                temp.append(item) if item else temp.append('')
-            result.append(temp)
-        for item in result and changed_string:
-            if str(item[0]) == str(changed_string[0]):
-                result.remove(item)
-
-        result.append(changed_string)
-        param_object[field.name] = listToArrayArray(client, result)
-        return param_object
+        object_array = TableAdapter.get_matrix(param_object[field.name])
+    # код выполняется локально
     else:
         if not getattr(param_object, field.name):
             setattr(param_object, field.name,
                     map(lambda x: x[1:] if not x[0] else x,
                         field.tablevalue.body))
+        object_array = getattr(param_object, field.name)
 
-        result = []
-        for _array in getattr(param_object, field.name):
-            temp = []
-            for item in _array:
-                temp.append(item) if item else temp.append('')
-            result.append(temp)
+    result = []
+    for _array in object_array:
+        temp = []
+        for item in _array:
+            temp.append(item) if item else temp.append('')
+        result.append(temp)
+    if changed_string:
         for item in result:
             if str(item[0]) == str(changed_string[0]):
                 result.remove(item)
 
-        result.append(changed_string)
+    result.append(changed_string)
+
+    if client:
+        param_object[field.name] = listToArrayArray(client, result)
+    else:
         setattr(param_object, field.name, result)
-        return param_object
+    return param_object
 
 
 def display_error(error, args, groups):
